@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2001 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2006 Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,12 +21,9 @@
 #define __MAIN_H__
 
 #include <glib.h>
-#include <gtk/gtkwidget.h>
 
 extern gchar *prog_version;
-extern gchar *startup_dir;
-extern gboolean debug_mode;
 
-void app_will_exit	(GtkWidget *widget, gpointer data);
+void app_will_exit	(gboolean	 force);
 
 #endif /* __MAIN_H__ */
